@@ -22,7 +22,7 @@ detect_os <- function() {
 generate_locale_archive <- function(os) {
   if (os == "Linux" || os == "Darwin") {
     paste0(
-      'LOCALE_ARCHIVE = if pkgs.system == \"x86_64-linux\" then ',
+      'LOCALE_ARCHIVE = if pkgs.stdenv.hostPlatform.system == \"x86_64-linux\" then ',
       '\"${pkgs.glibcLocales}/lib/locale/locale-archive\" else \"\";'
     )
   } else {
