@@ -7,16 +7,57 @@
 #'   packages for x86_64 Linux and macOS (Intel architectures for packages
 #'   released before 2021 and Apple Silicon from 2021 onwards). This function
 #'   automatically performs a backup of `~/.config/nix/nix.conf`, or creates one
-#'   if there is no `nix.conf` file. If you installed Nix by following the
-#'   instructions provided in the "Getting started" vignette and also followed
-#'   the instructions to install Cachix and configure the cache, you don't need
-#'   to run this. This function is useful in mainly two cases: if you somehow
-#'   mess up `~/.config/nix/nix.conf` and need to generate a new one from
-#'   scratch, or if you're using Nix inside Docker, write a `RUN Rscript -e
-#'   'rix::setup_cachix()'` statement to configure the cache there. Because
-#'   Docker runs using `root` by default no need to install the `cachix` client
-#'   to configure the cache, running `setup_cachix()` is enough. See the
-#'   'z - Advanced topic: Using Nix inside Docker' vignette for more details.
+#'   if there is no `nix.conf` file.
+#'
+#'   This is the recommended approach for configuring the cache, as it works
+#'   with both standard Nix installations and Determinate Nix installations.
+#'   After running this function, you also need to add yourself to
+#'   `trusted-users` so Nix allows you to use the cache. Run one of:
+#'
+#'   - **Linux**: `echo "trusted-users = root $USER" | sudo tee -a /etc/nix/nix.custom.conf && sudo systemctl restart nix-daemon`
+#'   - **macOS**: `echo "trusted-users = root $USER" | sudo tee -a /etc/nix/nix.custom.conf && sudo launchctl kickstart -k system/org.nixos.nix-daemon`
+#'
+#'   If you see warnings like "ignoring untrusted substituter", this means the
+#'   trusted-users configuration is not in place.
+#'
+#'   **NixOS users**: This function does not work on NixOS because the Nix
+#'   configuration is managed declaratively. Instead, configure the cache in
+#'   your system configuration. Without Home Manager, add this to your
+#'   `configuration.nix`:
+#'
+#'   ```
+#'   nix.settings = {
+#'     substituters = [
+#'       "https://cache.nixos.org"
+#'       "https://rstats-on-nix.cachix.org"
+#'     ];
+#'     trusted-public-keys = [
+#'       "cache.nixos.org-1:6NCHdD59X431o0gWypbMrAURkbJ16ZPMQFGspcDShjY="
+#'       "rstats-on-nix.cachix.org-1:vdiiVgocg6WeJrODIqdprZRUrhi1JzhBnXv7aWI6+F0="
+#'     ];
+#'   };
+#'   ```
+#'
+#'   With Home Manager, add this to your home configuration:
+#'
+#'   ```
+#'   nix.settings = {
+#'     substituters = [
+#'       "https://rstats-on-nix.cachix.org"
+#'     ];
+#'     trusted-public-keys = [
+#'       "rstats-on-nix.cachix.org-1:vdiiVgocg6WeJrODIqdprZRUrhi1JzhBnXv7aWI6+F0="
+#'     ];
+#'   };
+#'   ```
+#'
+#'   Other use cases include: if you somehow mess up `~/.config/nix/nix.conf`
+#'   and need to generate a new one from scratch, or if you're using Nix inside
+#'   Docker, write a `RUN Rscript -e 'rix::setup_cachix()'` statement to
+#'   configure the cache there. Because Docker runs using `root` by default no
+#'   need to install the `cachix` client to configure the cache, running
+#'   `setup_cachix()` is enough. See the 'z - Advanced topic: Using Nix inside
+#'   Docker' vignette for more details.
 #' @return Nothing; changes a file in the user's home directory.
 #' @export
 #' @examples
@@ -127,3 +168,58 @@ is_cachix_configured <- function(nix_conf_content) {
   substituter_line <- grep("substituters", nix_conf_content)
   any((grepl("rstats-on-nix", nix_conf_content[substituter_line])))
 }
+
+#' Check if running on NixOS
+#' @noRd
+#' @return Logical, TRUE if on NixOS
+is_nixos <- function() {
+  # NixOS has a special file at /etc/NIXOS
+  if (file.exists("/etc/NIXOS")) {
+    return(TRUE)
+  }
+  # Also check os-release as a fallback
+  if (file.exists("/etc/os-release")) {
+    os_release <- readLines("/etc/os-release", warn = FALSE)
+    if (any(grepl("ID=nixos", os_release, ignore.case = TRUE))) {
+      return(TRUE)
+    }
+  }
+  FALSE
+}
+
+#' Check if rstats-on-nix cache is configured anywhere
+#' @noRd
+#' @return Logical, TRUE if cachix is configured in any known location
+is_cachix_configured_anywhere <- function() {
+  # On NixOS, assume it's configured system-wide (users typically set it in
+  # configuration.nix which we can't easily read)
+  if (is_nixos()) {
+    return(TRUE)
+  }
+
+  # Check system-wide nix.conf
+  system_nix_conf <- "/etc/nix/nix.conf"
+  if (nix_conf_exists(system_nix_conf)) {
+    if (is_cachix_configured(readLines(system_nix_conf, warn = FALSE))) {
+      return(TRUE)
+    }
+  }
+
+  # Check user-level nix.conf
+  user_nix_conf <- "~/.config/nix/nix.conf"
+  if (nix_conf_exists(user_nix_conf)) {
+    if (is_cachix_configured(readLines(user_nix_conf, warn = FALSE))) {
+      return(TRUE)
+    }
+  }
+
+  # Check Determinate Nix custom conf
+  custom_nix_conf <- "/etc/nix/nix.custom.conf"
+  if (nix_conf_exists(custom_nix_conf)) {
+    if (is_cachix_configured(readLines(custom_nix_conf, warn = FALSE))) {
+      return(TRUE)
+    }
+  }
+
+  FALSE
+}
